# Solana Package

A Python library containing pb2 files to simplify parsing Solana blockchain data  on Kafka.

## Installation

Install easily via pip:

```bash
pip install bitquery-pb2-kafka-package
